@@ -1,9 +1,9 @@
-# @(#)Ident: Exception.pm 2013-09-03 11:15 pjf ;
+# @(#)Ident: Exception.pm 2013-10-03 12:51 pjf ;
 
 package Class::Usul::Exception;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.26.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.28.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use Unexpected::Types qw( Int Str );
@@ -13,7 +13,7 @@ with    q(Unexpected::TraitFor::ErrorLeader);
 with    q(Unexpected::TraitFor::ExceptionClasses);
 
 __PACKAGE__->has_exception( __PACKAGE__ );
-__PACKAGE__->ignore_class ( 'Class::Usul::IPC' );
+__PACKAGE__->ignore_class ( 'Class::Usul::IPC', 'Sub::Quote' );
 
 has '+class' => default => __PACKAGE__;
 
@@ -38,7 +38,7 @@ Class::Usul::Exception - Exception handling
 
 =head1 Version
 
-This documents version v0.26.$Rev: 1 $ of L<Class::Usul::Exception>
+This documents version v0.28.$Rev: 1 $ of L<Class::Usul::Exception>
 
 =head1 Synopsis
 
